@@ -1,9 +1,9 @@
 /* File getpix.c
- * May 14, 2020
+ * March 17, 2021
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2020
+   Copyright (C) 1996-2021
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -38,10 +38,10 @@ static int maxnfile = MAXFILES;
 static int maxnpix = MAXNPIX;
 
 static void usage();
-static void PrintPix();
+static int PrintPix();
 static void procpix();
 
-static char *RevMsg = "GETPIX WCSTools 3.9.6, 14 May 2020, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETPIX WCSTools 3.9.7, 26 April 2022, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;		/* If 1, print only program name and version */
@@ -67,6 +67,8 @@ static int syscoor = 0;         /* Input search coordinate system */
 static int identifier = 0;	/* If 1, identifier precedes x y in file */
 static int printtab = 0;	/* If 1, separate number with tabs */
 static int procinit = 1;	/* If 1, start mean and limits */
+static char *extensions;	/* Extension number(s) or name to read */
+static char *extension;		/* Extension number or name to read */
 static char pformat[8];		/* If not null, format for pixels without leading % */
 
 int
@@ -87,13 +89,19 @@ char **av;
     char *dstr = NULL;
     char *cstr;
     int systemp;
-    int i;
+    int i, j;
+    int nch;
     int npix = 0;
     int nfile;
     int ixnum, iynum;
     int ixrange, iyrange;
     char linebuff[1024];
     char listname[256];
+    char *fext, *fcomma;
+    char *namext;
+    char *extroot = NULL;
+    char *extroot0;
+    char *lastroot = NULL;
     char *line;
     char xstr[16], ystr[16], temp[64];
     int ix, iy;
@@ -102,6 +110,9 @@ char **av;
     FILE *fd;
     int *xp1, *yp1;
     double x, y;
+    int nfext = 0;
+    int nrmax=10;
+    struct Range *erange = NULL;
 
     nfile = 0;
     fn = (char **)calloc (maxnfile, sizeof(char *));
@@ -241,6 +252,55 @@ char **av;
 		case 'y':	/* Display by column instead of line */
 		    bycol++;
 		    break;
+	
+		case 'x': /* FITS extension to read */
+		    if (ac < 2)
+			usage();
+		    if (isnum (*(av+1)) || isrange (*(av+1))) {
+			extroot = NULL;
+			extensions = *++av;
+			ac--;
+			}
+		    else {
+			extroot = *++av;
+			lastroot = extroot + strlen (extroot);
+			extensions = extroot;
+			while (extensions < lastroot) {
+			    if (isrange (extensions))
+				break;
+			    else
+				extensions++;
+			    }
+			if (extensions == lastroot) {
+			    extensions = calloc (16, 1);
+			    if (strlen (extroot) > 0)
+				strcpy (extensions, "1-1000");
+			    else
+				strcpy (extensions, "0-1000");
+			    }
+			else {
+			    extroot0 = extroot;
+			    extroot = calloc (16, 1);
+			    strncpy (extroot, extroot0, extensions-extroot0);
+			    }
+			ac--;
+			}
+		    if (isrange (extensions)) {
+			erange = RangeInit (extensions, nrmax);
+			nfext = rgetn (erange);
+			if (verbose)
+			    fprintf (stderr, "Searching extensions %s\n", extensions);
+			}
+		    else {
+			extension = extensions;
+			if (extension)
+			    nfext = 1;
+			else
+			    nfext = 0;
+			if (verbose)
+			    fprintf (stderr, "Searching extension %s\n", extension);
+			}
+		    break;
 
 		default:
 		    usage();
@@ -432,7 +492,43 @@ char **av;
 	/* Process files already read from the command line */
 	if (nfile) {
 	    for (ifile = 0; ifile < nfile; ifile++) {
-		PrintPix (fn[ifile], xrange, yrange, npix, xpix, ypix);
+		strcpy (filename, fn[ifile]);
+		if (nfext > 1) {
+		    rstart (erange);
+		    extension = calloc (1, 8);
+		    for (i = 0; i < nfext; i++) {
+			j = rgeti4 (erange);
+			sprintf (extension, "%d", j);
+			nch = strlen (filename) + 2 + strlen (extension);
+			if (extroot)
+			    nch = nch + strlen (extroot);
+			namext = (char *) calloc (1, nch);
+			strcpy (namext, filename);
+			strcat (namext, ",");
+			if (extroot)
+			    strcat (namext,extroot);
+			strcat (namext, extension);
+			if (PrintPix (namext, xrange, yrange, npix, xpix, ypix)) {
+			    if (namext != NULL) {
+				free (namext);
+				namext = NULL;
+				}
+			    break;
+			    }
+			if (namext != NULL) {
+			    free (namext);
+			    namext = NULL;
+			    }
+			}
+		    if (extension != NULL) {
+			free (extension);
+			extension = NULL;
+			}
+		/* if (erange != NULL)
+		    free (erange); */
+		    }
+		else
+		    PrintPix (filename, xrange, yrange, npix, xpix, ypix);
 		}
 	    }
 
@@ -446,7 +542,40 @@ char **av;
 		}
 	    for (ifile = 0; ifile < nfile; ifile++) {
 		first_token (flist, 254, filename);
-		PrintPix (filename, xrange, yrange, npix, xpix, ypix);
+		if (nfext > 1) {
+		    rstart (erange);
+		    extension = calloc (1, 8);
+		    for (i = 0; i < nfext; i++) {
+			j = rgeti4 (erange);
+			sprintf (extension, "%d", j);
+			nch = strlen (filename) + 2 + strlen (extension);
+			if (extroot)
+			    nch = nch + strlen (extroot);
+			namext = (char *) calloc (1, nch);
+			strcpy (namext, filename);
+			strcat (namext, ",");
+			if (extroot)
+			    strcat (namext,extroot);
+			strcat (namext, extension);
+			if (PrintPix (namext, xrange, yrange, npix, xpix, ypix)) {
+			    if (namext != NULL) {
+				free (namext);
+				namext = NULL;
+				}
+			    break;
+			    }
+			if (namext != NULL) {
+			    free (namext);
+			    namext = NULL;
+			    }
+			}
+		    if (extension != NULL) {
+			free (extension);
+			extension = NULL;
+			}
+		    }
+		else
+		    PrintPix (filename, xrange, yrange, npix, xpix, ypix);
 		}
 	    fclose (flist);
 	    }
@@ -484,12 +613,13 @@ usage ()
     fprintf(stderr,"  -s: print x y value with no punctuation\n");
     fprintf(stderr,"  -t: separate columns in table with tabs not spaces \n");
     fprintf(stderr,"  -v: verbose\n");
+    fprintf(stderr,"  -x [range]: Read header for these extensions (no arg=all)\n");
     fprintf(stderr,"  -y: display by column instead of by row\n");
     exit (1);
 }
 
 
-static void
+static int
 PrintPix (name, xrange, yrange, npix, xpix, ypix)
 
 char *name;
@@ -529,19 +659,19 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	    free (irafheader);
 	    if (header == NULL) {
 		fprintf (stderr, "Cannot translate IRAF header %s/n",name);
-		return;
+		return (1);
 		}
 	    if ((image = irafrimage (header)) == NULL) {
 		hgetm (header,"PIXFIL", 255, pixname);
 		fprintf (stderr, "Cannot read IRAF pixel file %s\n", pixname);
 		free (irafheader);
 		free (header);
-		return;
+		return (1);
 		}
 	    }
 	else {
 	    fprintf (stderr, "Cannot read IRAF file %s\n", name);
-	    return;
+	    return (1);
 	    }
 	}
 
@@ -552,12 +682,12 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	    if ((image = fitsrimage (name, nbhead, header)) == NULL) {
 		fprintf (stderr, "Cannot read FITS image %s\n", name);
 		free (header);
-		return;
+		return (1);
 		}
 	    }
 	else {
 	    fprintf (stderr, "Cannot read FITS file %s\n", name);
-	    return;
+	    return (1);
 	    }
 	}
     if (printname) {
@@ -1184,7 +1314,7 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 
     free (header);
     free (image);
-    return;
+    return (0);
 }
 
 
@@ -1274,4 +1404,7 @@ double	dpix;	/* Current pixel value */
  * May 12 2020	Add -y to print columns as rows
  * May 14 2020	Clean up distinctions between image x and y and output columns and rows
  * May 14 2020	Add -o [format] to allow any legal C format for pixel display
+ * 
+ * Feb 10 2021	Add -x to read specified extension(s) from every input file
+ * Mar 17 2021	Fix bug when reading filename(s) from command line
  */
